pub enum SaveSettingsSync {
IfChanged,
Always,
}Expand description
A Command which saves settings to disk. This blocks the command queue until saving is complete.
Variants
IfChanged
Save settings only if they have changed since the most recent load or save.
Always
Save settings unconditionally.