pub struct SaveSettingsDeferred(pub Duration);Expand description
A Command which saves changed settings after a delay. This is debounced: issuing this command multiple times resets the delay timer each time. This is meant to be used for settings which change at a high frequency, such as dragging a slider which controls the game’s audio volume. The default delay is 1.0 seconds.
Tuple Fields
0: DurationTrait Implementations
Sourceimpl Command for SaveSettingsDeferred
impl Command for SaveSettingsDeferred
Sourcefn apply(self, world: &mut World)
fn apply(self, world: &mut World)
Applies this command, causing it to mutate the provided
world. Read moreSourcefn handle_error_with(
self,
error_handler: fn(BevyError, ErrorContext),
) -> impl Command<Out = ()>where
Self: Sized,
fn handle_error_with(
self,
error_handler: fn(BevyError, ErrorContext),
) -> impl Command<Out = ()>where
Self: Sized,